@@ -1,4 +1,6 @@
 import os
+import logging
+from datetime import datetime
 
 from testit_api_client import ApiClient
 from testit_api_client import Configuration
@@ -6,7 +8,7 @@ from testit_api_client.models import (
     TestRunV2PostShortModel,
     WorkItemIdModel,
     AttachmentPutModel
-    )
+)
 from testit_api_client.apis import TestRunsApi
 from testit_api_client.apis import AutoTestsApi
 from testit_api_client.apis import AttachmentsApi
@@ -30,9 +32,10 @@ class ApiClientWorker:
     def create_test_run(self):
         test_run_api = TestRunsApi(api_client=self.__api_client)
 
+        test_run_name = f'TestRun_{datetime.today().strftime("%Y-%m-%dT%H:%M:%S")}' if not self.__config.get_test_run_name() else self.__config.get_test_run_name()
         model = TestRunV2PostShortModel(
             project_id=self.__config.get_project_id(),
-            name=self.__config.get_test_run_name()
+            name=test_run_name
         )
 
         response = test_run_api.create_empty(test_run_v2_post_short_model=model)
@@ -47,7 +50,7 @@ class ApiClientWorker:
 
         response = test_run_api.get_test_run_by_id(self.__config.get_test_run_id())
 
-        test_results = response['testResults']
+        test_results = response['_data_store']['test_results']
 
         return Utils.autotests_parser(
             test_results,
@@ -79,7 +82,7 @@ class ApiClientWorker:
                         autotest_response['id'],
                         work_item_id_model=WorkItemIdModel(id=work_item_id))
                 except Exception as exc:
-                    print(f"Link with workItem {work_item_id} status: {exc.status}\n{exc.body}")
+                    logging.error(f"Link with workItem {work_item_id} status: {exc.status}\n{exc.body}")
 
         model = Converter.test_result_to_testrun_result_post_model(
             test_result,
@@ -100,7 +103,7 @@ class ApiClientWorker:
 
                     attachments.append(AttachmentPutModel(attachment_response['id']))
                 except Exception as exc:
-                    print(f'Load {path} status: {exc.status}\n{exc.body}')
+                    logging.error(f'Load {path} status: {exc.status}\n{exc.body}')
             else:
-                print(f'File ({path}) not found!')
+                logging.error(f'File ({path}) not found!')
         return attachments
