@@ -74,8 +74,7 @@ class Converter:
         return AutoTestResultsForTestRunModel(
             configuration_id,
             test_result['externalID'],
-            test_result['outcome'] if test_result['outcome'] else
-            'Failed' if test_result['traces'] else 'Passed',
+            test_result['outcome'],
             step_results=test_result['stepResults'],
             setup_results=test_result['setUpResults'],
             teardown_results=test_result['tearDownResults'],
@@ -85,7 +84,9 @@ class Converter:
             properties=test_result['properties'],
             links=cls.links_to_links_post_model(test_result['resultLinks']),
             duration=round(test_result['duration']),
-            message=test_result['message']
+            message=test_result['message'],
+            started_on=test_result.get('started_on', None),
+            completed_on=test_result.get('completed_on', None)
         )
 
     @staticmethod
@@ -163,12 +164,16 @@ class Converter:
             outcome: str,
             duration: str,
             parameters,
-            attachments):
+            attachments,
+            started_on=None,
+            completed_on=None):
         return AttachmentPutModelAutoTestStepResultsModel(
             title=title,
             description=description,
             duration=duration,
             outcome=outcome,
             parameters=parameters,
-            attachments=attachments
+            attachments=attachments,
+            started_on=started_on,
+            completed_on=completed_on
         )
